@@ -49,6 +49,10 @@ token_is_on_aligned_line <- function(pd_flat) {
   pd_flat$lag_newlines <- pd_flat$pos_id <- NULL
   pd_flat$.lag_spaces <- lag(pd_flat$spaces)
   pd_by_line <- split(pd_flat, line_idx)
+  pd_by_line[purrr::map_lgl(pd_by_line, ~ any(.x$stylerignore))] <- NULL
+  if (length(pd_by_line) < 1) {
+    return(TRUE)
+  }
   last_line_is_closing_brace_only <- nrow(last(pd_by_line)) == 1
   relevant_idx <- seq2(2, ifelse(last_line_is_closing_brace_only,
     length(pd_by_line) - 1,
@@ -80,19 +84,26 @@ token_is_on_aligned_line <- function(pd_flat) {
   if (any(starting_with_comma)) {
     return(FALSE)
   }
-  pd_is_multi_line <- map_lgl(pd_by_line, ~ any(.x$multi_line > 0L, na.rm = TRUE))
+  pd_is_multi_line <- map_lgl(
+    pd_by_line,
+    ~ any(.x$multi_line > 0L, na.rm = TRUE)
+  )
   if (any(pd_is_multi_line)) {
     return(FALSE)
   }
 
   pd_by_line <- alignment_drop_comments(pd_by_line) %>%
-    alignment_ensure_no_closing_brace(last_line_is_closing_brace_only) %>%
+    alignment_ensure_no_closing_brace(last_line_is_closing_brace_only)
+  if (length(pd_by_line) < 1) {
+    return(TRUE)
+  }
+  pd_by_line <- pd_by_line %>%
     alignment_ensure_trailing_comma()
   # now, pd only contains arguments separated by values, ideal for iterating
   # over columns.
-
   n_cols <- map_int(pd_by_line, ~ sum(.x$token == "','"))
   previous_line <- 0
+  current_col <- 0
   start_eval <- ifelse(alignment_col1_all_named(pd_by_line), 1, 2)
   for (column in seq2(1, max(n_cols))) {
     by_line <- alignment_serialize_column(pd_by_line, column) %>%
@@ -101,33 +112,47 @@ token_is_on_aligned_line <- function(pd_flat) {
       trimws(which = "right")
     # check 1: match by comma
     # might have fewer lines in subsequent columns.
-    current_col <- nchar(by_line)
+    max_previous_col <- max(current_col)
+
+    # first col has no leading ,
+    current_col <- nchar(by_line) - as.integer(column > 1)
     if (column > 1) {
-      previous_line <- previous_line[intersect(names(previous_line), names(by_line))]
+      previous_line <- previous_line[
+        intersect(names(previous_line), names(by_line))
+      ]
       # must add previous columns, as first column might not align
       current_col <- current_col + previous_line
     }
 
     is_aligned <- length(unique(current_col)) == 1L
-    if (!is_aligned) {
+    if (!is_aligned || length(current_col) < 2) {
       # check 2: left aligned after ,
-      current_col <- nchar(gsub("^(,[\\s\\t]*)[^ ]*.*$", "\\1", by_line, perl = TRUE))
+      current_col <- "^(,[\\s\\t]*)[^ ]*.*$" %>%
+        gsub("\\1", by_line, perl = TRUE) %>%
+        nchar() %>%
+        magrittr::subtract(1)
 
       if (column > 1) {
         # must add previous columns, as first column might not align
-        current_col <- current_col + previous_line
+        current_col <- previous_line + current_col
       }
-      is_aligned <- length(unique(current_col)) == 1L
+      if (length(current_col) > 1) {
+        is_aligned <- length(unique(current_col)) == 1L
+      } else {
+        is_aligned <- current_col - max_previous_col == 1
+        current_col <- max_previous_col + current_col
+      }
+
       if (is_aligned) {
         # if left aligned after ,
         start_eval <- 2
       }
     }
     if (is_aligned) {
-      previous_line <- previous_line + nchar(by_line)
+      previous_line <- current_col
       next
     }
-    # check 3: match by = (no extra spaces around it allowed.)
+    # check 3: match by = (no extra spaces around it allowed)
     # match left aligned after =
     start_after_eq <- regexpr("= [^ ]", by_line)
     names(start_after_eq) <- names(by_line)
@@ -137,14 +162,17 @@ token_is_on_aligned_line <- function(pd_flat) {
       if (length(start_after_eq) == 0) {
         return(FALSE)
       }
-      # when match via comma unsuccessful, matching by = must yield at least one =
+      # when match via , unsuccessful, matching by = must yield at least one =
       if (column == 1) {
         current_col <- start_after_eq
       } else {
         current_col <- start_after_eq +
           previous_line[intersect(names(previous_line), names(start_after_eq))]
       }
-      is_aligned <- length(unique(current_col)) == 1 && length(start_after_eq) > 1
+      is_aligned <- all(
+        length(unique(current_col)) == 1,
+        length(start_after_eq) > 1
+      )
       if (!is_aligned) {
         return(FALSE)
       }
