@@ -34,14 +34,30 @@ remove_roxygen_header <- function(text) {
 
 #' Add the roxygen mask to code
 #'
+#' This function compares `text` with `initial_text` to make sure a mask is only
+#' added to roxygen comments, not ordinary comments
 #' @param text Character vector with code.
+#' @param initial_text The roxygen code example to style with mask and
+#'   potentially ordinary comments.
 #' @param example_type Either 'examples' or 'examplesIf'.
 #' @keywords internal
 #' @importFrom purrr map2_chr
-add_roxygen_mask <- function(text, example_type) {
+add_roxygen_mask <- function(text, initial_text, example_type) {
   space <- ifelse(text == "", "", " ")
-  c(
+  out <- c(
     paste0("#' @", example_type, space[1], text[1]),
     map2_chr(space[-1], text[-1], ~ paste0("#'", .x, .y))
   )
+
+  ordinary_comment <- grep("^#[^']", initial_text, value = TRUE)
+  if (length(ordinary_comment) == 0L) {
+    return(out)
+  }
+  without_mask <- remove_roxygen_mask(out)
+  for (idx in seq_along(ordinary_comment)) {
+    to_replace <- which(ordinary_comment[idx] == without_mask)[1]
+    out[to_replace] <- ordinary_comment[idx]
+    without_mask[to_replace] <- NA
+  }
+  out
 }
