@@ -22,7 +22,7 @@ identify_start_to_stop_of_roxygen_examples_from_text <- function(text) {
 }
 
 identify_start_to_stop_of_roxygen_examples <- function(path) {
-  content <- xfun::read_utf8(path)
+  content <- read_utf8_bare(path)
   identify_start_to_stop_of_roxygen_examples_from_text(content)
 }
 
