@@ -71,10 +71,10 @@ set_and_assert_arg_filetype <- function(filetype) {
 #' @importFrom rlang abort
 #' @keywords internal
 assert_filetype <- function(lowercase_filetype) {
-  if (!all(lowercase_filetype %in% c("r", "rmd", "rnw", "rprofile"))) {
+  if (!all(lowercase_filetype %in% c("r", "rmd", "rmarkdown", "rnw", "rprofile"))) {
     abort(paste(
       "filetype must not contain other values than 'R', 'Rprofile',",
-      "'Rmd' or 'Rnw' (case is ignored)."
+      "'Rmd', 'Rmarkdown' or 'Rnw' (case is ignored)."
     ))
   }
 }
