@@ -1,9 +1,8 @@
 test_that("base_indention is respected in caching", {
-  on.exit(clear_testthat_cache())
+  local_test_setup(cache = TRUE)
   text <- c("1 + 1")
-  fresh_testthat_cache()
   without_indention <- style_text(text)
-  fresh_testthat_cache()
+  local_test_setup(cache = TRUE)
   style_text(text, base_indention = 5)
   expect_equal(
     style_text(text),
