@@ -9,17 +9,20 @@ test_that("can create a token that has relevant columns", {
   )
 
   expect_equal(
-    names(create_tokens("'{'", "{", pos_ids = 3)),
+    names(create_tokens("'{'", "{", pos_ids = 3, stylerignore = FALSE, indents = 0)),
     pd_names
   )
 })
 
 test_that("pos_id can be created", {
-  pd <- create_tokens("XZY_TEST", "test", pos_ids = 3)
+  pd <- create_tokens("XZY_TEST", "test", pos_ids = 3, stylerignore = FALSE, indents = 0)
   new_id <- create_pos_ids(pd, 1L, by = 0.4)
   expect_error(
     bind_rows(
-      create_tokens("XZY_TEST", "test", pos_ids = new_id),
+      create_tokens("XZY_TEST", "test",
+        pos_ids = new_id,
+        stylerignore = FALSE, indents = 0
+      ),
       pd
     ),
     NA
@@ -28,21 +31,30 @@ test_that("pos_id can be created", {
 
 
 test_that("unambiguous pos_id won't be created (down)", {
-  pd <- create_tokens("XZY_TEST", "test", pos_ids = 3)
+  pd <- create_tokens("XZY_TEST", "test",
+    pos_ids = 3,
+    stylerignore = FALSE, indents = 0
+  )
   new_id <- create_pos_ids(pd, 1L, by = 0.4)
   pd <- bind_rows(
-    create_tokens("XZY_TEST", "test", pos_ids = new_id),
+    create_tokens("XZY_TEST", "test",
+      pos_ids = new_id,
+      stylerignore = FALSE, indents = 0
+    ),
     pd
   )
   expect_error(create_pos_id(pd, 1L, by = 0.4))
 })
 
 test_that("unambiguous pos_id won't be created (up)", {
-  pd <- create_tokens("XZY_TEST", "test", pos_ids = 3)
+  pd <- create_tokens("XZY_TEST", "test",
+    pos_ids = 3,
+    stylerignore = FALSE, indents = 0
+  )
   new_id <- create_pos_ids(pd, 1L, by = 0.4, after = TRUE)
 
   pd <- bind_rows(
-    create_tokens("XZY_TEST", "test", pos_ids = new_id),
+    create_tokens("XZY_TEST", "test", pos_ids = new_id, stylerignore = FALSE, indents = 0),
     pd
   )
   expect_error(create_pos_id(pd, 1L, by = 0.4, after = TRUE))
